@@ -49,6 +49,11 @@ class Pluginsmime extends Plugin {
 	 */
 	private $openssl_error = "";
 
+	/**
+	 * Cipher to use.
+	 */
+	private $cipher = PLUGIN_SMIME_CIPHER;
+
 	/**
 	 * Called to initialize the plugin and register for hooks.
 	 */
@@ -65,9 +70,6 @@ class Pluginsmime extends Plugin {
 		if (version_compare(phpversion(), '5.4', '<')) {
 			$this->cipher = OPENSSL_CIPHER_3DES;
 		}
-		else {
-			$this->cipher = PLUGIN_SMIME_CIPHER;
-		}
 	}
 
 	/**
@@ -91,46 +93,52 @@ class Pluginsmime extends Plugin {
 	 */
 	public function execute($eventID, &$data) {
 		switch ($eventID) {
-		// Register plugin
-		case 'server.core.settings.init.before':
-			$this->onBeforeSettingsInit($data);
-			break;
-		// Verify a signed or encrypted message when an email is opened
-		case 'server.util.parse_smime.signed':
-			$this->onSignedMessage($data);
-			break;
+			// Register plugin
+			case 'server.core.settings.init.before':
+				$this->onBeforeSettingsInit($data);
+				break;
 
-		case 'server.util.parse_smime.encrypted':
-			$this->onEncrypted($data);
-			break;
-		// Add S/MIME property, which is send to the client
-		case 'server.module.itemmodule.open.after':
-			$this->onAfterOpen($data);
-			break;
-		// Catch uploaded certificate
-		case 'server.upload_attachment.upload':
-			$this->onUploadCertificate($data);
-			break;
-		// Sign email before sending
-		case 'server.core.operations.submitmessage':
-			$this->onBeforeSend($data);
-			break;
-		// Verify that we have public certificates for all recipients
-		case 'server.module.createmailitemmodule.beforesend':
-			$this->onCertificateCheck($data);
-			break;
+				// Verify a signed or encrypted message when an email is opened
+			case 'server.util.parse_smime.signed':
+				$this->onSignedMessage($data);
+				break;
 
-		case 'server.index.load.custom':
-			if ($data['name'] === 'smime_passphrase') {
-				include 'templates/passphrase.tpl.php';
-				exit();
-			}
-			if ($data['name'] === 'smime_passphrasecheck') {
-				// No need to do anything, this is just used to trigger
-				// the browser's autofill save password dialog.
-				exit();
-			}
-			break;
+			case 'server.util.parse_smime.encrypted':
+				$this->onEncrypted($data);
+				break;
+
+				// Add S/MIME property, which is send to the client
+			case 'server.module.itemmodule.open.after':
+				$this->onAfterOpen($data);
+				break;
+
+				// Catch uploaded certificate
+			case 'server.upload_attachment.upload':
+				$this->onUploadCertificate($data);
+				break;
+
+				// Sign email before sending
+			case 'server.core.operations.submitmessage':
+				$this->onBeforeSend($data);
+				break;
+
+				// Verify that we have public certificates for all recipients
+			case 'server.module.createmailitemmodule.beforesend':
+				$this->onCertificateCheck($data);
+				break;
+
+			case 'server.index.load.custom':
+				if ($data['name'] === 'smime_passphrase') {
+					include 'templates/passphrase.tpl.php';
+
+					exit;
+				}
+				if ($data['name'] === 'smime_passphrasecheck') {
+					// No need to do anything, this is just used to trigger
+					// the browser's autofill save password dialog.
+					exit;
+				}
+				break;
 		}
 	}
 
@@ -163,10 +171,11 @@ class Pluginsmime extends Plugin {
 		$messageClass = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 		$messageClass = $messageClass[PR_MESSAGE_CLASS];
 		if ($messageClass !== 'IPM.Note.SMIME' &&
-		    $messageClass !== 'IPM.Note.SMIME.SignedEncrypt' &&
-		    $messageClass !== 'IPM.Note.deferSMIME' &&
-		    $messageClass !== 'IPM.Note.deferSMIME.SignedEncrypt')
+			$messageClass !== 'IPM.Note.SMIME.SignedEncrypt' &&
+			$messageClass !== 'IPM.Note.deferSMIME' &&
+			$messageClass !== 'IPM.Note.deferSMIME.SignedEncrypt') {
 			return;
+		}
 
 		$recipients = $data['action']['props']['smime'];
 		$missingCerts = [];
@@ -259,7 +268,8 @@ class Pluginsmime extends Plugin {
 					$searchKeys = mapi_getprops($message, [PR_SEARCH_KEY, PR_SENT_REPRESENTING_SEARCH_KEY]);
 					$searchKey = $searchKeys[PR_SEARCH_KEY] ?? $searchKeys[PR_SENT_REPRESENTING_SEARCH_KEY];
 					if ($searchKey) {
-						$emailAddr = $trim(strtolower(explode(':', $searchKey)[1]));
+						$sk = strtolower(explode(':', $searchKey)[1]);
+						$emailAddr = trim($sk);
 					}
 				}
 			}
@@ -300,14 +310,18 @@ class Pluginsmime extends Plugin {
 				$importCert = file_get_contents($outcert);
 				$parsedImportCert = openssl_x509_parse($importCert);
 				$parsedUserCert = openssl_x509_parse($userCert);
-				if (!$signed_ok || $openssl_error_code === OPENSSL_CA_VERIFY_FAIL)
+				if (!$signed_ok || $openssl_error_code === OPENSSL_CA_VERIFY_FAIL) {
 					continue;
+				}
 
 				// CA Checks out
 				$caCerts = $this->extractCAs($tmpfname);
 				// If validTo and validFrom are more in the future, emailAddress matches and OCSP check is valid, import newer certificate
-				if ($parsedImportCert['validTo'] > $parsedUserCert['validTo'] && $parsedImportCert['validFrom'] > $parsedUserCert['validFrom'] &&
-					getCertEmail($parsedImportCert) === getCertEmail($parsedUserCert) && verifyOCSP($importCert, $caCerts, $this->message) &&
+				if (is_array($parsedImportCert) && is_array($parsedUserCert) &&
+					$parsedImportCert['validTo'] > $parsedUserCert['validTo'] &&
+					$parsedImportCert['validFrom'] > $parsedUserCert['validFrom'] &&
+					getCertEmail($parsedImportCert) === getCertEmail($parsedUserCert) &&
+					verifyOCSP($importCert, $caCerts, $this->message) &&
 					$importMessageCert !== false) {
 					// Redundant
 					$importMessageCert = true;
@@ -334,8 +348,8 @@ class Pluginsmime extends Plugin {
 				if (!is_array($parsedImportCert) || !verifyOCSP($userCert, $caCerts, $this->message)) {
 					$importMessageCert = false;
 				}
-				// We don't have a certificate from the MAPI UserStore or LDAP, so we will set $userCert to $importCert
-				// so that we can verify the message according to the be imported certificate.
+			// We don't have a certificate from the MAPI UserStore or LDAP, so we will set $userCert to $importCert
+			// so that we can verify the message according to the be imported certificate.
 			}
 			else { // No pubkey
 				$importMessageCert = false;
@@ -374,7 +388,7 @@ class Pluginsmime extends Plugin {
 	 * The key should be unlocked and stored in the EncryptionStore for a successful decrypt
 	 * If the key isn't in the session, we give the user a message to unlock his certificate.
 	 *
-	 * @param {mixed} $data array of data from hook
+	 * @param mixed $data array of data from hook
 	 */
 	public function onEncrypted($data) {
 		// Cert unlocked, decode message
@@ -384,20 +398,20 @@ class Pluginsmime extends Plugin {
 		$this->message['type'] = 'encrypted';
 		$encryptionStore = EncryptionStore::getInstance();
 		$pass = $encryptionStore->get('smime');
+
+		$tmpFile = tempnam(sys_get_temp_dir(), true);
+		// Write mime header. Because it's not provided in the attachment, otherwise openssl won't parse it
+		$fp = fopen($tmpFile, 'w');
+		fwrite($fp, "Content-Type: application/pkcs7-mime; name=\"smime.p7m\"; smime-type=enveloped-data\n");
+		fwrite($fp, "Content-Transfer-Encoding: base64\nContent-Disposition: attachment; filename=\"smime.p7m\"\n");
+		fwrite($fp, "Content-Description: S/MIME Encrypted Message\n\n");
+		fwrite($fp, chunk_split(base64_encode($data['data']), 72) . "\n");
+		fclose($fp);
 		if (isset($pass) && !empty($pass)) {
 			$certs = readPrivateCert($this->getStore(), $pass, false);
 			// create random file for saving the encrypted and body message
-			$tmpFile = tempnam(sys_get_temp_dir(), true);
 			$tmpDecrypted = tempnam(sys_get_temp_dir(), true);
 
-			// Write mime header. Because it's not provided in the attachment, otherwise openssl won't parse it
-			$fp = fopen($tmpFile, 'w');
-			fwrite($fp, "Content-Type: application/pkcs7-mime; name=\"smime.p7m\"; smime-type=enveloped-data\n");
-			fwrite($fp, "Content-Transfer-Encoding: base64\nContent-Disposition: attachment; filename=\"smime.p7m\"\n");
-			fwrite($fp, "Content-Description: S/MIME Encrypted Message\n\n");
-			fwrite($fp, chunk_split(base64_encode($data['data']), 72) . "\n");
-			fclose($fp);
-
 			$decryptStatus = false;
 			// If multiple private certs were decrypted with supplied password
 			if (!$certs['cert'] && count($certs) > 0) {
@@ -453,7 +467,31 @@ class Pluginsmime extends Plugin {
 			}
 		}
 		else {
-			$this->message['info'] = SMIME_UNLOCK_CERT;
+			// it might also be a signed message only. Verify it.
+			$msg = tempnam(sys_get_temp_dir(), true);
+			$ret = openssl_pkcs7_verify($tmpFile, PKCS7_NOVERIFY, null, [], null, $msg);
+			$content = file_get_contents($msg);
+			unlink($tmpFile);
+			unlink($msg);
+			if ($ret === true && !empty($content)) {
+				$copyProps = mapi_getprops($data['message'], [PR_MESSAGE_DELIVERY_TIME, PR_SENDER_ENTRYID, PR_SENT_REPRESENTING_ENTRYID]);
+				mapi_inetmapi_imtomapi(
+					$GLOBALS['mapisession']->getSession(),
+					$data['store'],
+					$GLOBALS['mapisession']->getAddressbook(),
+					$data['message'],
+					$content,
+					['parse_smime_signed' => true]
+				);
+				// Manually set time back to the received time, since mapi_inetmapi_imtomapi overwrites this
+				mapi_setprops($data['message'], $copyProps);
+				$this->message['type'] = 'encryptsigned';
+				$this->message['info'] = SMIME_DECRYPT_SUCCESS;
+				$this->message['success'] = SMIME_STATUS_SUCCESS;
+			}
+			else {
+				$this->message['info'] = SMIME_UNLOCK_CERT;
+			}
 		}
 
 		if (!encryptionStoreExpirationSupport()) {
@@ -466,7 +504,7 @@ class Pluginsmime extends Plugin {
 	/**
 	 * Function which calls verifyMessage to verify if the message isn't malformed during transport.
 	 *
-	 * @param {mixed} $data array of data from hook
+	 * @param mixed $data array of data from hook
 	 */
 	public function onSignedMessage($data) {
 		$this->message['type'] = 'signed';
@@ -484,14 +522,16 @@ class Pluginsmime extends Plugin {
 		if ($openssl_return === -1) {
 			$this->message['info'] = SMIME_ERROR;
 			$this->message['success'] = SMIME_STATUS_FAIL;
+
 			return;
-		// Verification was successful
+			// Verification was successful
 		}
-		elseif ($openssl_return) {
+		if ($openssl_return) {
 			$this->message['info'] = SMIME_SUCCESS;
 			$this->message['success'] = SMIME_STATUS_SUCCESS;
+
 			return;
-		// Verification was not successful, display extra information.
+			// Verification was not successful, display extra information.
 		}
 		$this->message['success'] = SMIME_STATUS_FAIL;
 		if ($openssl_errors === OPENSSL_CA_VERIFY_FAIL) {
@@ -510,7 +550,7 @@ class Pluginsmime extends Plugin {
 	 *
 	 * TODO: investigate if we can move away from this hook
 	 *
-	 * @param {mixed} $data
+	 * @param mixed $data
 	 */
 	public function onAfterOpen($data) {
 		if (isset($this->message) && !empty($this->message)) {
@@ -525,23 +565,25 @@ class Pluginsmime extends Plugin {
 	 * - Verifies that the email address is equal to the
 	 * - Verifies that the certificate isn't expired and inform user.
 	 *
-	 * @param {mixed} $data
+	 * @param mixed $data
 	 */
 	public function onUploadCertificate($data) {
-		if ($data['sourcetype'] !== 'certificate')
+		if ($data['sourcetype'] !== 'certificate') {
 			return;
+		}
 		$passphrase = $_POST['passphrase'];
 		$saveCert = false;
 		$tmpname = $data['tmpname'];
 		$message = '';
+		$imported = false;
 
 		$certificate = file_get_contents($tmpname);
 		$emailAddress = $GLOBALS['mapisession']->getSMTPAddress();
-		list($message, $publickey, $publickeyData) = validateUploadedPKCS($certificate, $passphrase, $emailAddress);
+		list($message, $publickey, $publickeyData, $imported) = validateUploadedPKCS($certificate, $passphrase, $emailAddress);
 
 		// All checks completed successful
 		// Store private cert in users associated store (check for duplicates)
-		if (empty($message)) {
+		if ($imported) {
 			$certMessage = getMAPICert($this->getStore());
 			// TODO: update to serialNumber check
 			if ($certMessage && $certMessage[0][PR_MESSAGE_DELIVERY_TIME] == $publickeyData['validTo_time_t']) {
@@ -549,7 +591,7 @@ class Pluginsmime extends Plugin {
 			}
 			else {
 				$saveCert = true;
-				$root = mapi_msgstore_openentry($this->getStore(), null);
+				$root = mapi_msgstore_openentry($this->getStore());
 				// Remove old certificate
 				/*
 				if($certMessage) {
@@ -594,7 +636,7 @@ class Pluginsmime extends Plugin {
 	 * If the PR_MESSAGE_CLASS is set to a signed email (IPM.Note.SMIME.Multipartsigned), this function
 	 * will convert the mapi message to RFC822, sign the eml and attach the signed email to the mapi message.
 	 *
-	 * @param {mixed} $data from php hook
+	 * @param mixed $data from php hook
 	 */
 	public function onBeforeSend(&$data) {
 		$store = $data['store'];
@@ -604,21 +646,24 @@ class Pluginsmime extends Plugin {
 		$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 		$messageClass = $props[PR_MESSAGE_CLASS];
 
-		if (!isset($messageClass))
+		if (!isset($messageClass)) {
 			return;
+		}
 		if (stripos($messageClass, 'IPM.Note.deferSMIME') === false &&
-		    stripos($messageClass, 'IPM.Note.SMIME') === false)
+			stripos($messageClass, 'IPM.Note.SMIME') === false) {
 			return;
+		}
 
 		// FIXME: for now return when we are going to sign but we don't have the passphrase set
 		// This should never happen sign
-		$encryptionStore = \EncryptionStore::getInstance();
+		$encryptionStore = EncryptionStore::getInstance();
 		if (($messageClass === 'IPM.Note.deferSMIME.SignedEncrypt' ||
-		    $messageClass === 'IPM.Note.deferSMIME.MultipartSigned' ||
-		    $messageClass === 'IPM.Note.SMIME.SignedEncrypt' ||
-		    $messageClass === 'IPM.Note.SMIME.MultipartSigned') &&
-		    !$encryptionStore->get('smime'))
+			$messageClass === 'IPM.Note.deferSMIME.MultipartSigned' ||
+			$messageClass === 'IPM.Note.SMIME.SignedEncrypt' ||
+			$messageClass === 'IPM.Note.SMIME.MultipartSigned') &&
+			!$encryptionStore->get('smime')) {
 			return;
+		}
 		// NOTE: setting message class to IPM.Note, so that mapi_inetmapi_imtoinet converts the message to plain email
 		// and doesn't fail when handling the attachments.
 		mapi_setprops($message, [PR_MESSAGE_CLASS => 'IPM.Note']);
@@ -663,23 +708,23 @@ class Pluginsmime extends Plugin {
 
 		// Sign then Encrypt email
 		switch ($messageClass) {
-		case 'IPM.Note.deferSMIME.SignedEncrypt':
-		case 'IPM.Note.SMIME.SignedEncrypt':
-			$tmpFile = tempnam(sys_get_temp_dir(), true);
-			$this->sign($tmpSendEmail, $tmpFile, $message, $signedAttach, $smimeProps);
-			$this->encrypt($tmpFile, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
-			unlink($tmpFile);
-			break;
+			case 'IPM.Note.deferSMIME.SignedEncrypt':
+			case 'IPM.Note.SMIME.SignedEncrypt':
+				$tmpFile = tempnam(sys_get_temp_dir(), true);
+				$this->sign($tmpSendEmail, $tmpFile, $message, $signedAttach, $smimeProps);
+				$this->encrypt($tmpFile, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
+				unlink($tmpFile);
+				break;
 
-		case 'IPM.Note.deferSMIME.MultipartSigned':
-		case 'IPM.Note.SMIME.MultipartSigned':
-			$this->sign($tmpSendEmail, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
-			break;
+			case 'IPM.Note.deferSMIME.MultipartSigned':
+			case 'IPM.Note.SMIME.MultipartSigned':
+				$this->sign($tmpSendEmail, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
+				break;
 
-		case 'IPM.Note.deferSMIME':
-		case 'IPM.Note.SMIME':
-			$this->encrypt($tmpSendEmail, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
-			break;
+			case 'IPM.Note.deferSMIME':
+			case 'IPM.Note.SMIME':
+				$this->encrypt($tmpSendEmail, $tmpSendSmimeEmail, $message, $signedAttach, $smimeProps);
+				break;
 		}
 
 		// Save the signed message as attachment of the send email
@@ -704,8 +749,8 @@ class Pluginsmime extends Plugin {
 	/**
 	 * Function to sign an email.
 	 *
-	 * @param object $infile       File eml to be encrypted
-	 * @param object $outfile      File
+	 * @param string $infile       File eml to be encrypted
+	 * @param string $outfile      File
 	 * @param object $message      Mapi Message Object
 	 * @param object $signedAttach
 	 * @param array  $smimeProps
@@ -741,8 +786,8 @@ class Pluginsmime extends Plugin {
 	/**
 	 * Function to encrypt an email.
 	 *
-	 * @param object $infile       File eml to be encrypted
-	 * @param object $outfile      File
+	 * @param string $infile       File eml to be encrypted
+	 * @param string $outfile      File
 	 * @param object $message      Mapi Message Object
 	 * @param object $signedAttach
 	 * @param array  $smimeProps
@@ -847,11 +892,11 @@ class Pluginsmime extends Plugin {
 	 * Retrieves the public certificates stored in the MAPI UserStore and belonging to the
 	 * emailAdddress, returns "" if there is no certificate for that user.
 	 *
-	 * @param {String} emailAddress
+	 * @param string emailAddress
 	 * @param mixed $emailAddress
 	 * @param mixed $multiple
 	 *
-	 * @return {String} $certificate
+	 * @return string $certificate
 	 */
 	public function getPublicKey($emailAddress, $multiple = false) {
 		$certificates = [];
@@ -862,8 +907,9 @@ class Pluginsmime extends Plugin {
 			foreach ($certs as $cert) {
 				$pubkey = mapi_msgstore_openentry($this->getStore(), $cert[PR_ENTRYID]);
 				$certificate = "";
-				if ($pubkey == false)
+				if ($pubkey == false) {
 					continue;
+				}
 				// retrieve pkcs#11 certificate from body
 				$stream = mapi_openproperty($pubkey, PR_BODY, IID_IStream, 0, 0);
 				$stat = mapi_stream_stat($stream);
@@ -881,12 +927,12 @@ class Pluginsmime extends Plugin {
 	/**
 	 * Function which is used to check if there is a public certificate for the provided emailAddress.
 	 *
-	 * @param {String} emailAddress emailAddres of recipient
-	 * @param {Boolean} gabUser is the user of PR_ADDRTYPE == ZARAFA
+	 * @param string emailAddress emailAddres of recipient
+	 * @param bool gabUser is the user of PR_ADDRTYPE == ZARAFA
 	 * @param mixed $emailAddress
 	 * @param mixed $gabUser
 	 *
-	 * @return {Boolean} true if public certificate exists
+	 * @return bool true if public certificate exists
 	 */
 	public function pubcertExists($emailAddress, $gabUser = false) {
 		if ($gabUser) {
@@ -897,7 +943,7 @@ class Pluginsmime extends Plugin {
 			}
 		}
 
-		$root = mapi_msgstore_openentry($this->getStore(), null);
+		$root = mapi_msgstore_openentry($this->getStore());
 		$table = mapi_folder_getcontentstable($root, MAPI_ASSOCIATED);
 
 		// Restriction for public certificates which are from the recipient of the email, are active and have the correct message_class
@@ -930,7 +976,7 @@ class Pluginsmime extends Plugin {
 	 * Example error from openssl_error_string(): error:21075075:PKCS7 routines:PKCS7_verify:certificate verify error
 	 * Note that openssl_error_string() returns an error when verifying is successful, this is a bug in PHP https://bugs.php.net/bug.php?id=50713.
 	 *
-	 * @return {String}
+	 * @return string
 	 */
 	public function extract_openssl_error() {
 		// TODO: should catch more errors by using while($error = @openssl_error_string())
@@ -985,14 +1031,15 @@ class Pluginsmime extends Plugin {
 	 */
 	public function importCertificate($cert, $certData, $type = 'public', $force = false) {
 		$certEmail = getCertEmail($certData);
-		if ($this->pubcertExists($certEmail) && !$force && $type !== 'private')
+		if ($this->pubcertExists($certEmail) && !$force && $type !== 'private') {
 			return;
+		}
 		$issued_by = "";
 		foreach (array_keys($certData['issuer']) as $key) {
 			$issued_by .= $key . '=' . $certData['issuer'][$key] . "\n";
 		}
 
-		$root = mapi_msgstore_openentry($this->getStore(), null);
+		$root = mapi_msgstore_openentry($this->getStore());
 		$assocMessage = mapi_folder_createmessage($root, MAPI_ASSOCIATED);
 		// TODO: write these properties down.
 		mapi_setprops($assocMessage, [
@@ -1018,9 +1065,8 @@ class Pluginsmime extends Plugin {
 	/**
 	 * Function which returns the fingerprint (hash) of the certificate.
 	 *
-	 * @param {string} $cert certificate body as a string
-	 * @param {string} $hash optional hash algorithm
-	 * @param mixed $body
+	 * @param string $hash optional hash algorithm
+	 * @param mixed  $body
 	 */
 	public function fingerprint_cert($body, $hash = 'md5') {
 		// TODO: Note for PHP > 5.6 we can use openssl_x509_fingerprint
@@ -1085,7 +1131,7 @@ class Pluginsmime extends Plugin {
 	 * Called when the core Settings class is initialized and ready to accept sysadmin default
 	 * settings. Registers the sysadmin defaults for the example plugin.
 	 *
-	 * @param {mixed} $data Reference to the data of the triggered hook
+	 * @param mixed $data Reference to the data of the triggered hook
 	 */
 	public function onBeforeSettingsInit(&$data) {
 		$data['settingsObj']->addSysAdminDefaults([
@@ -1110,8 +1156,9 @@ class Pluginsmime extends Plugin {
 	 * @return array with properties
 	 */
 	public function getSenderAddress($mapiMessage) {
-		if (method_exists($GLOBALS['operations'], 'getSenderAddress'))
+		if (method_exists($GLOBALS['operations'], 'getSenderAddress')) {
 			return $GLOBALS["operations"]->getSenderAddress($mapiMessage);
+		}
 
 		$messageProps = mapi_getprops($mapiMessage, [PR_SENT_REPRESENTING_ENTRYID, PR_SENDER_ENTRYID]);
 		$senderEntryID = isset($messageProps[PR_SENT_REPRESENTING_ENTRYID]) ? $messageProps[PR_SENT_REPRESENTING_ENTRYID] : $messageProps[PR_SENDER_ENTRYID];
@@ -1122,15 +1169,15 @@ class Pluginsmime extends Plugin {
 				$userprops = mapi_getprops($senderUser, [PR_ADDRTYPE, PR_DISPLAY_NAME, PR_EMAIL_ADDRESS, PR_SMTP_ADDRESS, PR_OBJECT_TYPE, PR_RECIPIENT_TYPE, PR_DISPLAY_TYPE, PR_DISPLAY_TYPE_EX, PR_ENTRYID]);
 
 				$senderStructure = [];
-				$senderStructure["props"]['entryid'] = bin2hex($userprops[PR_ENTRYID]);
-				$senderStructure["props"]['display_name'] = isset($userprops[PR_DISPLAY_NAME]) ? $userprops[PR_DISPLAY_NAME] : '';
-				$senderStructure["props"]['email_address'] = isset($userprops[PR_EMAIL_ADDRESS]) ? $userprops[PR_EMAIL_ADDRESS] : '';
-				$senderStructure["props"]['smtp_address'] = isset($userprops[PR_SMTP_ADDRESS]) ? $userprops[PR_SMTP_ADDRESS] : '';
-				$senderStructure["props"]['address_type'] = isset($userprops[PR_ADDRTYPE]) ? $userprops[PR_ADDRTYPE] : '';
+				$senderStructure["props"]['entryid'] = isset($userprops[PR_ENTRYID]) ? bin2hex($userprops[PR_ENTRYID]) : '';
+				$senderStructure["props"]['display_name'] = $userprops[PR_DISPLAY_NAME] ?? '';
+				$senderStructure["props"]['email_address'] = $userprops[PR_EMAIL_ADDRESS] ?? '';
+				$senderStructure["props"]['smtp_address'] = $userprops[PR_SMTP_ADDRESS] ?? '';
+				$senderStructure["props"]['address_type'] = $userprops[PR_ADDRTYPE] ?? '';
 				$senderStructure["props"]['object_type'] = $userprops[PR_OBJECT_TYPE];
 				$senderStructure["props"]['recipient_type'] = MAPI_TO;
-				$senderStructure["props"]['display_type'] = isset($userprops[PR_DISPLAY_TYPE]) ? $userprops[PR_DISPLAY_TYPE] : MAPI_MAILUSER;
-				$senderStructure["props"]['display_type_ex'] = isset($userprops[PR_DISPLAY_TYPE_EX]) ? $userprops[PR_DISPLAY_TYPE_EX] : MAPI_MAILUSER;
+				$senderStructure["props"]['display_type'] = $userprops[PR_DISPLAY_TYPE] ?? MAPI_MAILUSER;
+				$senderStructure["props"]['display_type_ex'] = $userprops[PR_DISPLAY_TYPE_EX] ?? MAPI_MAILUSER;
 			}
 		}
 		catch (MAPIException $e) {
