@@ -163,17 +163,9 @@ class AttachmentState {
 	 */
 	public function isInlineAttachment($attachment) {
 		$props = mapi_attach_getprops($attachment, [PR_ATTACH_CONTENT_ID, PR_ATTACHMENT_HIDDEN, PR_ATTACH_FLAGS]);
-		$isContentIdSet = isset($props[PR_ATTACH_CONTENT_ID]);
-
-		// PR_ATTACHMENT_HIDDEN property will not be available in case of embedded attachment.
-		$isHidden = isset($props[PR_ATTACHMENT_HIDDEN]) ? $props[PR_ATTACHMENT_HIDDEN] : false;
 		$isInlineAttachmentFlag = (isset($props[PR_ATTACH_FLAGS]) && $props[PR_ATTACH_FLAGS] & 4) ? true : false;
 
-		if ($isContentIdSet && $isHidden && $isInlineAttachmentFlag) {
-			return true;
-		}
-
-		return false;
+		return isset($props[PR_ATTACH_CONTENT_ID]) && $isInlineAttachmentFlag;
 	}
 
 	/**
@@ -185,14 +177,10 @@ class AttachmentState {
 	 */
 	public function isContactPhoto($attachment) {
 		$attachmentProps = mapi_attach_getprops($attachment, [PR_ATTACHMENT_CONTACTPHOTO, PR_ATTACHMENT_HIDDEN]);
-		$isHidden = $attachmentProps[PR_ATTACHMENT_HIDDEN];
-		$isAttachmentContactPhoto = (isset($attachmentProps[PR_ATTACHMENT_CONTACTPHOTO]) && $attachmentProps[PR_ATTACHMENT_CONTACTPHOTO]) ? true : false;
+		$isHidden = $attachmentProps[PR_ATTACHMENT_HIDDEN] ?? false;
+		$isAttachmentContactPhoto = $attachmentProps[PR_ATTACHMENT_CONTACTPHOTO] ?? false;
 
-		if ($isAttachmentContactPhoto && $isHidden) {
-			return true;
-		}
-
-		return false;
+		return $isAttachmentContactPhoto && $isHidden;
 	}
 
 	/**
